pub trait ResetStream: StreamOnce {
type Checkpoint: Clone;
// Required methods
fn checkpoint(&self) -> Self::Checkpoint;
fn reset(&mut self, checkpoint: Self::Checkpoint) -> Result<(), Self::Error>;
}Expand description
A StreamOnce which can create checkpoints which the stream can be reset to
Required Associated Types
type Checkpoint: Clone
Required Methods
Sourcefn checkpoint(&self) -> Self::Checkpoint
fn checkpoint(&self) -> Self::Checkpoint
Creates a Checkpoint at the current position which can be used to reset the stream
later to the current position
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".